@@ -8,9 +8,11 @@ def _parse_datetime_cols(df: pd.DataFrame) -> pd.DataFrame:
     """Finds datetime columns in the DataFrame and converts them to datetime
 
     Args:
-        df: pandas.DataFrame()
+        df: pandas.DataFrame
     Returns:
-        DataFrame with datetime columns converted according to standard AEMO format
+        :class:`pandas.DataFrame` with datetime columns converted according to standard
+        AEMO
+        format
     """
     dt_cols = {
         "DATETIME",
@@ -42,9 +44,9 @@ def _parse_id_cols(df: pd.DataFrame) -> pd.DataFrame:
     """Finds relevant ID columns in the DataFrame and converts them to cateogries
 
     Args:
-        df: pandas.DataFrame()
+        df: pandas.DataFrame
     Returns:
-        DataFrame with ID columns converted to categories
+        :class:`pandas.DataFrame` with ID columns converted to categories
     """
     id_cols = {
         "CONSTRAINTID",
@@ -62,15 +64,33 @@ def _parse_id_cols(df: pd.DataFrame) -> pd.DataFrame:
     return df
 
 
+def _parse_predispatch_seq_no(df: pd.DataFrame) -> pd.DataFrame:
+    """Parses `PREDISPATCHSEQNO` as datetime and adds `PREDISPATCH_RUN_DATETIME`
+
+    Args:
+        df: pandas.DataFrame
+    Returns:
+        :class:`pandas.DataFrame` with additional column `PREDISPATCH_RUN_DATETIME`
+    """
+    df["PREDISPATCHSEQNO"] = df["PREDISPATCHSEQNO"].astype(int).astype(str)
+    parsed = df["PREDISPATCHSEQNO"].str.extract(r"^([0-9]{8})([0-9]{2})$")
+    year_month_day = pd.to_datetime(parsed[0], format="%Y%m%d")
+    hour_min = ((parsed[1].astype(int) - 1) * pd.Timedelta(minutes=30)).add(
+        pd.Timedelta(hours=4, minutes=30)
+    )
+    df["PREDISPATCH_RUN_DATETIME"] = year_month_day + hour_min  # type: ignore
+    return df
+
+
 def clean_forecast_csv(filepath_or_buffer: Union[str, Path]) -> pd.DataFrame:
     """Given a forecast csv filepath or buffer, reads and cleans the forecast csv.
 
     Cleans artefacts in the forecast csv files.
 
     Args:
-        filepath_or_buffer: As for pandas.read_csv()
+        filepath_or_buffer: As for :func:`pandas.read_csv`
     Returns:
-        Cleaned DataFrame
+        Cleaned :class:`pandas.DataFrame` with forecast data
     """
     # skip AEMO metadata
     df = pd.read_csv(filepath_or_buffer, skiprows=1, low_memory=False)
@@ -80,4 +100,6 @@ def clean_forecast_csv(filepath_or_buffer: Union[str, Path]) -> pd.DataFrame:
     df = df.drop(drop_cols, axis="columns")
     df = _parse_datetime_cols(df)
     df = _parse_id_cols(df)
+    if "PREDISPATCHSEQNO" in df.columns:
+        df = _parse_predispatch_seq_no(df)
     return df
